/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.function;

import org.apache.paimon.catalog.Identifier;
import org.apache.paimon.types.DataField;

import java.util.List;
import java.util.Map;
import java.util.Optional;

/** Interface for function. */
public interface Function {

    String name();

    String fullName();

    Identifier identifier();

    Optional<List<DataField>> inputParams();

    Optional<List<DataField>> returnParams();

    boolean isDeterministic();

    Map<String, FunctionDefinition> definitions();

    FunctionDefinition definition(String name);

    String comment();

    Map<String, String> options();
}
